@@ -246,7 +246,7 @@ check_performance <- function(object, select_strategy = "control if available",
                summarise_num(extr_res$final_n[restrict_idx]),
                summarise_num(extr_res$sum_ys[restrict_idx]),
                summarise_num(extr_res$ratio_ys[restrict_idx]),
-               mean(extr_res$final_status != "max"),
+               mean(extr_res$final_status[restrict_idx] != "max"),
                mean(extr_res$final_status[restrict_idx] == "superiority"),
                mean(extr_res$final_status[restrict_idx] == "equivalence"),
                mean(extr_res$final_status[restrict_idx] == "futility"),
@@ -300,7 +300,7 @@ check_performance <- function(object, select_strategy = "control if available",
                            summarise_num(extr_boot$final_n[restrict_idx]),
                            summarise_num(extr_boot$sum_ys[restrict_idx]),
                            summarise_num(extr_boot$ratio_ys[restrict_idx]),
-                           mean(extr_boot$final_status != "max"),
+                           mean(extr_boot$final_status[restrict_idx] != "max"),
                            mean(extr_boot$final_status[restrict_idx] == "superiority"),
                            mean(extr_boot$final_status[restrict_idx] == "equivalence"),
                            mean(extr_boot$final_status[restrict_idx] == "futility"),
